//HELP FILE ADDED
//solves for the TE-mode cutoff wavenumbers in a dielectric slab 
function [u,v,err] = dslab(R,Nit)
if argn(2)==0, help dslab; return; end
if argn(2)==1, Nit=3; end
M = floor(2*R/%pi);                      // number of modes/solutions = M+1
m = 0:M;
Rc = m*%pi/2;                            // cutoff radii
r = R - Rc;
V = ((%pi/4 + Rc)/cos(%pi/4) - Rc)/sqrt(log(1.25));
u1 = (sqrt(1 + 2*R*r) - 1)/R;           // solutions near cutoff
u2 = (R-m)/(R+1)*%pi/2;                  // solutions far from cutoff
a1 = exp(-r.^2./V.^2);                  // interpolating weights
a2 = 1 - a1;
u = Rc + a1.*u1 + a2.*u2;               // Lotspeich approximation
for i=1:Nit,                            // Newton iteration, skipped if Nit=0
    v = sqrt(R^2 - u.*u);
    F = u.*tan(u-Rc) - v;               // function F(u) = u*tan(u-Rc) - v
    G = v./u + u./v + (R^2)./u;           // derivative F'(u) to order O(F)
    u = u - real(F./G);                 // Newton's update
end
v = sqrt(R^2 - u.^2);
err = norm(u.*tan(u-Rc) - v);
endfunction
