function [lm,Zm] = lmin(ZL,Z0,type1)
//lmin - find locations of voltage minima and maxima
//[lm,Zm] = lmin(ZL,Z0,type)
//[lm,Zm] = lmin(ZL,Z0)      (equivalent to type='min')
//ZL   = load impedance
//Z0   = line impedance
//type = 'min', 'max' (default 'min')
//lm = location in wavelengths
//Zm = real-valued wave impedance at lm
//calculate G = z2g(ZL,Z0), S = swr(G), th = angle(G), then
//lmin = (th + pi)/4/pi, Zmin = Z0/S,
//lmax = th/4/pi (or, (th+2*pi)/4/pi, if th<0), Zmax = S*Z0


if argn(2)==0, help lmin; return; end
if argn(2)==2, type1='min'; end
G = z2g(ZL,Z0);
S = swr(G);
th = atan(imag(G)./real(G));

if type1=='min' then
    if th<0 then th = th+2*%pi, end
    lm = th/4/%pi;
    Zm = S*Z0;    

else
    lm = (th + %pi)/4/%pi;
    Zm = Z0/S;
end
endfunction
