function [a, dph] = sector(d, ph1, ph2, N, Astop)
if argn(2)==0, help sector; return; end
  
if Astop > 21,                         // compute Kaiser's D factor
    D = (Astop - 7.95)/14.36;
else
    D = 0.922;
end
if Astop <= 21,                         // compute Kaiser window shape parameter
    alpha = 0;
elseif Astop < 50
    alpha = 0.5842*(Astop - 21)^0.4 + 0.07886*(Astop - 21);
else
    alpha = 0.1102*(Astop - 8.7);
end   
ph1 = ph1*%pi/180;
ph2 = ph2*%pi/180;

phac = (ph1 + ph2)/2;                    //center of angular sector
phw = ph2 - ph1;                        // full width of sector
ps0 = 2*%pi*d*cos(phac)*cos(phw/2);       // effective scan phase
psp = 2*%pi*d*sin(phac)*sin(phw/2);      // passband frequency in psi-space
dps = 2*%pi*D/(N-1);                     // Kaiser transition width in psi-space
psb = psp + dps/2;                      // ideal cutoff frequency in psi-space
r=N-fix(N./2).*2
s = (1-r)/2;                           // s=0, for N odd, and s=1/2 for N even
M = (N-r)/2;
I0alpha = I0(alpha);                    // window normalization factor
a=0;
w=0;
for m=1:M,
   a(m) = sin(psb*(m-s)) / (%pi*(m-s));
   w(m) = I0(alpha*sqrt(1 - (m/M)^2)) / I0alpha;
end
a=a';
w=w';
if r==1,                                // odd N=2*M+1
   a = [flipdim(a,2), psb/%pi, a];         // symmetrized ideal weights
   w = [flipdim(w,2), 1, w];               //symmetrized Kaiser window
else                                    // even N=2*M
   a = [flipdim(a,2)  a];
   w = [flipdim(w,2) w];
end
a = a .* w;                             // windowed lowpass array weights
a = scan(a, ps0);                       // scanned weights
dph=dps/(2*%pi*d.*sin(phac));//estimated transition width in phi-space                                               
dph = dph.*180/%pi;                       
endfunction
